@@ -1,6 +1,8 @@
 from typing import Literal
 
 from astropy.io import fits
+from astropy.time import Time
+from astropy.time import TimeDelta
 from dkist_processing_common.tasks import WriteL1Frame
 
 
@@ -37,3 +39,21 @@ class WriteL1Data(WriteL1Frame):
             header[f"NBIN{i}"] = 1
 
         return header
+
+    def _calculate_date_end(self, header: fits.Header) -> str:
+        """
+        Calculate the VBI specific version of the "DATE-END" keyword.
+
+        Parameters
+        ----------
+        header
+            The input fits header
+
+        Returns
+        -------
+        The isot formatted string of the DATE-END keyword value
+        """
+        return (
+            Time(header["DATE-BEG"], format="isot", precision=6)
+            + TimeDelta(float(header["TEXPOSUR"]) / 1000, format="sec")
+        ).to_value("isot")
